Las Cruces, NM

Skip to Main Content
Covid-19 Alerts Access Local Coronavirus Updates here: Read On...

# Agenda Center

View current agendas and minutes for all boards, committees, and commissions.

### Tools

- RSS
- Notify Me®

### Search Agendas by:

Time Period Time Period

1. Time Period
2. Last Week
3. Last Month
4. Last 6 Months
5. Last Year

Start Date
End Date
Word or Phrase
Select a Category Search

1. All Categories
2. 2020 Census Complete Count Committee
3. ADA Advisory Committee
4. AHLBTF Advisory Board
5. Airport Advisory Board
6. Animal Care Task Force
7. Animal Service Center of the Mesilla Valley
8. Board of Commissioners for Las Cruces Utilities
9. Capital Improvements Advisory Committee
10. City Art Board
11. City Council
12. Communications PRC
13. Comprehensive Plan Advisory Committee
14. CVB Advisory Board
15. DAC Juvenile Justice Continuum Board
16. Development Review Committee

1. Downtown Parking Committee
2. Economic Development PRC
3. El Paseo & South Solano Ad Hoc Committee
4. Finance PRC
5. Health and Human Services Advisory Board
6. Health PRC
7. Historic Preservation Commission
8. Housing PRC
9. Infrastructure/CIP PRC
10. Integrated Pest Management Committee
11. Las Cruces Economic Recovery Ad Hoc Board
12. LC Partnership for Community Schools
13. Mayor's Suicide Prevention Taskforce
14. Metro Narcotics
15. MPO Bicycle and Pedestrian Facilities Committee
16. MPO Policy Committee

1. MPO Technical Advisory Committee
2. Parks & Rec Advisory Board
3. Parks and Recreation Youth Board
4. Planning and Zoning Commission
5. Public Safety PRC
6. Quality of Life PRC
7. Selection Advisory Committee
8. Senior Programs Advisory Board
9. South Mesquite Design Review Board
10. Thomas Branigan Memorial Library Board
11. Transit Advisory Board
12. TSI PRC
13. University District Citizen's Design Review Board
14. Utility Customer Advisory Group
15. VA Advisory Board

◄ Back to all agendas

## ▼Airport Advisory Board

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Nov 19, 2020 — Posted Nov 16, 2020 11:47 AM Airport Advisory Board Meeting Agenda for November 19, 2020 |  | Download ▼ HTML PDF Packet

## ▼Board of Commissioners for Las Cruces Utilities

- 2020

Agenda | Minutes | Media | Download
--- | --- | --- | ---
#### Nov 19, 2020 — Posted Nov 16, 2020 3:23 PM Potential Quorum Notice |  |  | Download ▼ HTML PDF Packet
#### Nov 12, 2020 — Posted Nov 2, 2020 4:29 PM LCU Board Regular Meeting for November 12, 2020, will focus on the Administrative Report, Three Resolutions on Consent, and Seven Resolutions for Discussion. |  |  | Download ▼ HTML PDF Packet Previous Versions

## ▼Capital Improvements Advisory Committee

- 2020

Agenda | Minutes | Media | Download
--- | --- | --- | ---
#### Nov 19, 2020 — Posted Nov 13, 2020 12:34 PM CIAC Agenda for November 19, 2020 , will focus on Utilities Department Impact Fee Updates and Seven Year Report for Park Impact Fees Reviews for: Utilities, Parks & Rec, and Public Safety. |  |  | Download ▼ HTML PDF Packet Previous Versions

## ▼City Art Board

- 2020

Agenda | Minutes | Media | Download
--- | --- | --- | ---
#### Dec 8, 2020 — Posted Dec 3, 2020 8:13 AM City Art Board Agenda |  |  | Download ▼ HTML PDF Packet
#### Nov 10, 2020 — Posted Nov 5, 2020 9:11 AM City Art Board Agenda |  |  | Download ▼ HTML PDF Packet

## ▼DAC Juvenile Justice Continuum Board

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 9, 2020 — Posted Dec 4, 2020 8:20 AM DOÑA ANA COUNTY JUVENILE JUSTICE CONTINUUM BOARD AGENDA |  | Download ▼ HTML PDF Packet Previous Versions

## ▼Development Review Committee

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 2, 2020 — Posted Nov 30, 2020 11:10 AM DRC Meeting on December 2, 2020 - CANCELLED |  | Download ▼ HTML PDF Packet
#### Nov 18, 2020 — Posted Nov 13, 2020 8:04 AM DRC Meeting on November 18, 2020 - CANCELLED |  | Download ▼ HTML PDF Packet

## ▼Downtown Parking Committee

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Nov 19, 2020 — Posted Nov 16, 2020 6:11 AM Downtown Parking Committee Meeting |  | Download ▼ HTML PDF Packet

## ▼Economic Development PRC

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Nov 18, 2020 — Posted Nov 13, 2020 3:06 PM Economic Development PRC Meeting |  | Download ▼ HTML PDF Packet

## ▼Health PRC

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 2, 2020 — Posted Nov 23, 2020 10:53 AM Health PRC Meeting December 2, 2020 |  | Download ▼ HTML PDF Packet Previous Versions

## ▼Historic Preservation Commission

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 14, 2020 — Posted Dec 10, 2020 2:49 PM Historic Preservation Commission Meeting on December 14, 2020 |  | Download ▼ HTML PDF Packet
#### Nov 17, 2020 — Posted Nov 17, 2020 9:08 AM Historic Preservation Committee Meeting on November 20, 2020 |  | Download ▼ HTML PDF Packet
#### Nov 9, 2020 — Posted Nov 5, 2020 1:00 PM Historic Preservation Commission Meeting on November 9, 2020 |  | Download ▼ HTML PDF Packet Previous Versions

## ▼Housing PRC

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Nov 18, 2020 — Posted Nov 16, 2020 6:20 AM Housing PRC Meeting on November 18, 2020 - Cancelled |  | Download ▼ HTML PDF Packet

## ▼Las Cruces Economic Recovery Ad Hoc Board

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 3, 2020 — Posted Nov 24, 2020 11:11 AM Las Cruces Economic Recovery Ad Hoc Board Agenda for December 3, 2020 |  | Download ▼ HTML PDF Packet
#### Nov 19, 2020 — Amended Nov 18, 2020 9:40 AM Cancelled- Las Cruces Economic Recovery Ad-Hoc Board Agenda for November 19, 2020 |  | Download ▼ HTML PDF Packet Previous Versions

## ▼Mayor's Suicide Prevention Taskforce

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Nov 18, 2020 — Posted Nov 18, 2020 12:00 PM The Las Cruces Mayor's Suicide Prevention Task Force |  | Download ▼ HTML PDF Packet

## ▼Parks & Rec Advisory Board

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Nov 19, 2020 — Posted Nov 12, 2020 2:43 PM Parks & Recreation Advisory Board Meeting |  | Download ▼ HTML PDF Packet

## ▼Planning and Zoning Commission

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 14, 2020 — Posted Dec 10, 2020 3:14 PM Planning & Zoning Commission Potential Quorum Notice for December 13-19, 2020 |  | Download ▼ HTML PDF Packet
#### Nov 24, 2020 — Posted Nov 9, 2020 9:59 AM P&Z Agenda for November 24, 2020 |  | Download ▼ HTML PDF Packet

## ▼Quality of Life PRC

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 9, 2020 — Posted Dec 2, 2020 3:13 PM Quality of Life Policy Review Committee Meeting Agenda |  | Download ▼ HTML PDF Packet

## ▼Senior Programs Advisory Board

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 10, 2020 — Amended Dec 10, 2020 7:26 AM Senior Programs Advisory Board Meeting December 10, 2020 CANCELLED |  | Download ▼ HTML PDF Packet Previous Versions
#### Nov 12, 2020 — Posted Nov 4, 2020 7:51 AM CANCELLED - Senior Programs Advisory Board Meeting - November 12, 2020 |  | Download ▼ HTML PDF Packet

## ▼Transit Advisory Board

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 3, 2020 — Posted Nov 26, 2020 3:00 PM LAS CRUCES AREA TRANSIT ADVISORY BOARD MEETING AGENDA |  | Download ▼ HTML PDF Packet Previous Versions

## ▼TSI PRC

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 1, 2020 — Posted Nov 25, 2020 8:28 AM Transportation-Sustainability-Infrastructure PRC Meeting Agenda for December 1, 2020 |  | Download ▼ HTML PDF Packet

## ▼University District Citizen's Design Review Board

- 2020

Agenda | Minutes | Download
--- | --- | ---
#### Dec 7, 2020 — Posted Dec 2, 2020 11:22 AM University District Citizen Design Review Committee Meeting on December 7, 2020 - Cancelled |  | Download ▼ HTML PDF Packet

Live
Work
Play
City Council & utility board meetings
Transparency
Report an Issue
Agendas
Notify Me®
Government Websites by CivicPlus®
[]